--- loncom/homework/grades.pm	2010/08/30 09:47:32	1.636
+++ loncom/homework/grades.pm	2010/10/22 15:29:57	1.638
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Grading handler
 #
-# $Id: grades.pm,v 1.636 2010/08/30 09:47:32 wenzelju Exp $
+# $Id: grades.pm,v 1.638 2010/10/22 15:29:57 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -3861,7 +3861,7 @@ ENDPICK
 }
 
 sub checkforfile_js {
-    my $alertmsg = &mt('Please use the "Choose File" button to select a file from your local directory.');
+    my $alertmsg = &mt('Please use the browse button to select a file from your local directory.');
     my $result = &Apache::lonhtmlcommon::scripttag(<<CSVFORMJS);
     function checkUpload(formname) {
 	if (formname.upfile.value == "") {
@@ -4057,6 +4057,9 @@ sub csvuploadassign {
                     my $pcr=$entries{$fields{$dest}} / $wgt;
                     my $award=($pcr == 0) ? 'incorrect_by_override'
                                           : 'correct_by_override';
+                    if ($pcr>1) {
+                       push(@skipped,&mt("[_1]: point value larger than weight","$username:$domain"));
+                    }
                     $grades{"resource.$part.awarded"}=$pcr;
                     $grades{"resource.$part.solved"}=$award;
                     $points{$part}=1;
@@ -9182,9 +9185,9 @@ sub handler {
     &Apache::lonenc::check_decrypt(\$symb);                             
 
     $ssi_error = 0;
-    if ($symb eq '' || $command eq '') {
+    if (($symb eq '' || $command eq '') && ($env{'request.course.id'})) {
 #
 # Not called from a resource
 #    
         &startpage($request,undef,[],1,1);
         &select_problem($request);
@@ -9182,9 +9185,9 @@ sub handler {
 #
-# Not called from a resource
+# Not called from a resource, but inside a course
 #    
         &startpage($request,undef,[],1,1);